
Access management
-------

**Description:**

Whenever your application contains administration and management functions you should
put on restrictions for visiting these functionalities in order to reduce an attackers
attack vector on your services since they are not directly accessible for them.

**Solution:**

Verify that access to administration and management functions within the Web Service 
Application is limited to web service administrators.

For example, they could only be accessible from within a restricted source IP range.


